summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorTim Potter <tpot@samba.org>2002-01-20 22:50:23 +0000
committerTim Potter <tpot@samba.org>2002-01-20 22:50:23 +0000
commit1f670cfb275ee34e66f504cd35b1c790840999bf (patch)
tree514ac3583c4472490ca4b0a2aa28c5bf01366d22
parent03a4ebbfac78bff612b3973c4cc612f0eb95ade6 (diff)
downloadsamba-1f670cfb275ee34e66f504cd35b1c790840999bf.tar.gz
samba-1f670cfb275ee34e66f504cd35b1c790840999bf.tar.bz2
samba-1f670cfb275ee34e66f504cd35b1c790840999bf.zip
Spelling fixes.
(This used to be commit e67c7c5852624bcdd5c565ea5f00b143aaf7fee4)
-rw-r--r--source3/auth/auth.c12
-rw-r--r--source3/libsmb/namequery.c2
-rw-r--r--source3/smbd/negprot.c14
3 files changed, 15 insertions, 13 deletions
diff --git a/source3/libsmb/namequery.c b/source3/libsmb/namequery.c
index 926cda9dcb..d90cd6a7ea 100644
--- a/source3/libsmb/namequery.c
+++ b/source3/libsmb/namequery.c
@@ -64,6 +64,8 @@ static struct node_status *parse_node_status(char *p, int *num_names)
ret[i].type = CVAL(p,15);
ret[i].flags = p[16];
p += 18;
+ DEBUG(10, ("%s#%02x: flags = 0x%02x\n", ret[i].name,
+ ret[i].type, ret[i].flags));
}
return ret;
}
diff --git a/source3/smbd/negprot.c b/source3/smbd/negprot.c
index 5899f0af52..04e6eb445b 100644
--- a/source3/smbd/negprot.c
+++ b/source3/smbd/negprot.c
@@ -29,23 +29,23 @@ BOOL global_encrypted_passwords_negotiated = False;
BOOL global_spnego_negotiated = False;
struct auth_context *negprot_global_auth_context = NULL;
-static void get_challange(char buff[8])
+static void get_challenge(char buff[8])
{
NTSTATUS nt_status;
const uint8 *cryptkey;
/* We might be called more than once, muliple negprots are premitted */
if (negprot_global_auth_context) {
- DEBUG(3, ("get challange: is this a secondary negprot? negprot_global_auth_context is non-NULL!\n"));
+ DEBUG(3, ("get challenge: is this a secondary negprot? negprot_global_auth_context is non-NULL!\n"));
(negprot_global_auth_context->free)(&negprot_global_auth_context);
}
- DEBUG(10, ("get challange: creating negprot_global_auth_context\n"));
+ DEBUG(10, ("get challenge: creating negprot_global_auth_context\n"));
if (!NT_STATUS_IS_OK(nt_status = make_auth_context_subsystem(&negprot_global_auth_context))) {
DEBUG(0, ("make_auth_context_subsystem returned %s", get_nt_error_msg(nt_status)));
smb_panic("cannot make_negprot_global_auth_context!\n");
}
- DEBUG(10, ("get challange: getting challange\n"));
+ DEBUG(10, ("get challenge: getting challenge\n"));
cryptkey = negprot_global_auth_context->get_ntlm_challenge(negprot_global_auth_context);
memcpy(buff, cryptkey, 8);
}
@@ -100,7 +100,7 @@ static int reply_lanman1(char *inbuf, char *outbuf)
SSVAL(outbuf,smb_vwv1,secword);
/* Create a token value and add it to the outgoing packet. */
if (global_encrypted_passwords_negotiated) {
- get_challange(smb_buf(outbuf));
+ get_challenge(smb_buf(outbuf));
}
Protocol = PROTOCOL_LANMAN1;
@@ -141,7 +141,7 @@ static int reply_lanman2(char *inbuf, char *outbuf)
/* Create a token value and add it to the outgoing packet. */
if (global_encrypted_passwords_negotiated) {
- get_challange(smb_buf(outbuf));
+ get_challenge(smb_buf(outbuf));
}
Protocol = PROTOCOL_LANMAN2;
@@ -286,7 +286,7 @@ static int reply_nt1(char *inbuf, char *outbuf)
if (!negotiate_spnego) {
/* Create a token value and add it to the outgoing packet. */
if (global_encrypted_passwords_negotiated) {
- get_challange(p);
+ get_challenge(p);
}
SSVALS(outbuf,smb_vwv16+1,8);
p += 8;
diff --git a/source3/auth/auth.c b/source3/auth/auth.c
index 6b68fa631a..892102a5ef 100644
--- a/source3/auth/auth.c
+++ b/source3/auth/auth.c
@@ -52,7 +52,7 @@ static const uint8 *get_ntlm_challenge(struct auth_context *auth_context)
TALLOC_CTX *mem_ctx;
if (auth_context->challenge.length) {
- DEBUG(5, ("get_ntlm_challange (auth subsystem): returning previous challenge (normal)\n"));
+ DEBUG(5, ("get_ntlm_challenge (auth subsystem): returning previous challenge (normal)\n"));
return auth_context->challenge.data;
}
@@ -70,7 +70,7 @@ static const uint8 *get_ntlm_challenge(struct auth_context *auth_context)
continue;
}
- mem_ctx = talloc_init_named("auth_get_challange for module %s", auth_method->name);
+ mem_ctx = talloc_init_named("auth_get_challenge for module %s", auth_method->name);
if (!mem_ctx) {
smb_panic("talloc_init_named() failed!");
}
@@ -156,10 +156,10 @@ static BOOL check_domain_match(const char *user, const char *domain)
* @param user_info Contains the user supplied components, including the passwords.
* Must be created with make_user_info() or one of its wrappers.
*
* @param auth_info Supplies the challanges and some other data.
* Must be created with make_auth_info(), and the challanges should be
* filled in, either at creation or by calling the challange geneation
* function auth_get_challange().
*
* @param server_info If successful, contains information about the authenticaion,
* including a SAM_ACCOUNT struct describing the user.
@@ -156,10 +156,10 @@ static BOOL check_domain_match(const char *user, const char *domain)
* Must be created with make_user_info() or one of its wrappers.
*
- * @param auth_info Supplies the challanges and some other data.
- * Must be created with make_auth_info(), and the challanges should be
- * filled in, either at creation or by calling the challange geneation
- * function auth_get_challange().
+ * @param auth_info Supplies the challenges and some other data.
+ * Must be created with make_auth_info(), and the challenges should be
+ * filled in, either at creation or by calling the challenge geneation
+ * function auth_get_challenge().
*
* @param server_info If successful, contains information about the authenticaion,